ExceptionCode

Enum ExceptionCode 

#[repr(u8)]
pub enum ExceptionCode { IllegalFunction = 1, IllegalDataAddress = 2, IllegalDataValue = 3, ServerDeviceFailure = 4, }
Modbus exception codes as defined in the Modbus Application Protocol Specification V1.1b3.

These codes are used in exception responses (function code | 0x80) to indicate the type of error that occurred when processing a request.

Variants



IllegalFunction = 1

0x01: Illegal Function - The function code is not supported by the server.



IllegalDataAddress = 2

0x02: Illegal Data Address - The addressed register does not exist.



IllegalDataValue = 3

0x03: Illegal Data Value - The quantity of items to read/write is invalid.



ServerDeviceFailure = 4

0x04: Server Device Failure - Unrecoverable device failure.