ObjectId

Enum ObjectId 

pub enum ObjectId {
    Err,
    Basic(BasicObjectId),
    Regular(RegularObjectId),
    Extended(ExtendedObjectId),
    Reserved(u8),
}
Represents any valid Modbus Device Identification Object ID.

Variants



Err

Sentinel default used before parsing a concrete object identifier. This value should not appear in a valid decoded response.



Basic(BasicObjectId)

Basic Device Identification Object IDs (0x00 - 0x02).



Regular(RegularObjectId)

Regular Device Identification Object IDs (0x03 - 0x06).



Extended(ExtendedObjectId)

Extended Device Identification Object IDs (0x80 - 0xFF).



Reserved(u8)

Reserved range (0x07 - 0x7F).