ModbusSerialConfig

Struct ModbusSerialConfig 

pub struct ModbusSerialConfig<const PORT_PATH_LEN: usize = 64> {
    pub port_path: String<PORT_PATH_LEN>,
    pub mode: SerialMode,
    pub baud_rate: BaudRate,
    pub data_bits: DataBits,
    pub stop_bits: u8,
    pub parity: Parity,
    pub response_timeout_ms: u32,
    pub retry_attempts: u8,
    pub retry_backoff_strategy: BackoffStrategy,
    pub retry_jitter_strategy: JitterStrategy,
    pub retry_random_fn: Option<RetryRandomFn>,
}
Configuration parameters for establishing a Modbus Serial connection.

Fields

port_path: String<PORT_PATH_LEN>

The path to the serial port (e.g., “/dev/ttyUSB0” or “COM1”).

mode: SerialMode

The serial mode to use (RTU or ASCII).

baud_rate: BaudRate

Communication speed in bits per second (e.g., 9600, 115200).

data_bits: DataBits

Number of data bits per character (typically DataBits::Eight for RTU, DataBits::Seven for ASCII).

stop_bits: u8

Number of stop bits (This will be recalculated before calling the transport layer).

parity: Parity

The parity checking mode.

response_timeout_ms: u32

Timeout for waiting for a response in milliseconds.

retry_attempts: u8

Number of retries for failed operations.

retry_backoff_strategy: BackoffStrategy

Backoff strategy used when scheduling retries.

retry_jitter_strategy: JitterStrategy

Optional jitter strategy applied on top of retry backoff delay.

retry_random_fn: Option<RetryRandomFn>

Optional application-provided random callback used by jitter.